/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.JMSException;
import javax.jms.Message;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_3007_TestCase
 *
 * Tests that the correlation ID of request messages are set to a non-null 
 * value when using the sca:correlationID correlation scheme on a reference.
 *   
 */
public class BJM_3007_TestCase extends BaseJMSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	JMSTestConfiguration config = new JMSTestConfiguration();
    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
    	config.input             = "BJM_3007 request message";
    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked service1 operation1 invoked with BJM_3007 request message</return>";
    	config.composite         = "Test_" + config.testName + ".composite";
    	config.contributionNames = new String[] { "BJM_3007", "BJM_General", "BJM_General" + _Lang };
        config.destinationName   = "TEST_BJM_3007_Receive_Queue";
        config.mockServiceDestinationName = "TEST_BJM_3007_Service_Queue";
        config.mockServiceCorrelationScheme = "correlationID";

    	return config;
    }

    String serviceRequestCorrelationID;
    @Override
    protected void checkServiceRequest(Message m) throws JMSException {
        this.serviceRequestCorrelationID = m.getJMSCorrelationID();
    }

    public String checkReplyMessage( Message reply ) throws Exception {
        if( serviceRequestCorrelationID == null || serviceRequestCorrelationID.length() < 1) {
            return "correlationID not set on request message";
        }
        return super.checkReplyMessage(reply);
    }

    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class BJM_3007_TestCase