/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.Message;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;


/**
 * Client for BJM_4004_TestCase
 * 
 * If no wireFormat element is specified in a JMS binding then SCA runtimes MUST use
 * wireFormat.jmsDefault as the default
 * 
 * tests if SCA runtimes uses wireFormat.jmsDefault as the default 
 * if no wireFormat element is specified in a JMS binding 
 * An invalid message is sent, exception should be thrown 
 */
public class BJM_4004_TestCase extends BaseJMSTestRunner {

	   protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_4004 request message";
	    	config.output[0]         = "exception";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4004", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4004_Queue";
	 
	    	return config;
	    }
	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess ) throws Exception {
	    	TextMessage textMsg = (TextMessage)super.createRequestMessage(input, sess);
	        textMsg.setText("This is not XML format: "+input);
	        return textMsg;
	    }
	    
	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }
}  // end class BJM_4004_TestCase