/*
 * Copyright(C) OASIS(R) 2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_bjm;

import javax.jms.BytesMessage;
import javax.jms.Destination;
import javax.jms.Message;
import javax.jms.Session;

import org.junit.Ignore;
import org.junit.Test;

import client.TestConfiguration;

/**
 * Client for BJM_4005B_TestCase
 * 
 * When using the default wire format an SCA runtime MUST be able to receive both
 * JMS text and bytes messages
 * 
 * This is the Bytes message test
 */
public class BJM_4005B_TestCase extends BaseJMSTestRunner  {

	   protected TestConfiguration getTestConfiguration() {
	    	JMSTestConfiguration config = new JMSTestConfiguration();
	    	config.testName          = this.getClass().getSimpleName().substring(0, 8);
	    	config.input             = "BJM_4005 request message";
	    	config.output[0]         = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><return>service1 operation1 invoked with BJM_4005 request message</return>";
	    	config.composite         = "Test_" + config.testName + ".composite";
	    	config.contributionNames = new String[] { "BJM_4005", "BJM_General", "BJM_General" + _Lang };
	        config.destinationName   = "TEST_BJM_4005_Queue";
	 
	    	return config;
	    }
	   
	    /**
	     * Create the request message.
	     * @param input - input string
	     * @param sess - the JMS session
	     * @return the request message.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public Message createRequestMessage( String input, Session sess ) throws Exception {
	    	String messageBody ="<?xml version=\"1.0\" encoding=\"UTF-8\"?><operation1>"+input+"</operation1>";
	    	
	    	Destination replyQueue = sess.createTemporaryQueue();
	    	BytesMessage bytesMsg = sess.createBytesMessage();
	    	bytesMsg.setJMSReplyTo(replyQueue);
	    	bytesMsg.writeBytes(messageBody.getBytes());
	    	
	        return bytesMsg;
	    }
	    
	    /**
	     * Check the reply message.
	     *
	     * @param reply - the reply message
	     * @return the output.
	     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
	     */
	    public String checkReplyMessage( Message reply ) throws Exception {
	        String output = "No reply";

	        if( reply instanceof BytesMessage) {
	        	byte[] b = new byte[1024];  
	        	int len = -1;
	        	BytesMessage message = (BytesMessage)reply;
	        	StringBuffer text = new StringBuffer();
	        	while((len = message.readBytes(b))!=-1){
	        		text.append(new String(b, 0, len));
	        	}
	        	output = text.toString();
	        	
	        } else {
	            System.out.println("Reply is "+reply);
	        }

	        return output;
	    }
	    
	    /**
	     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
	     */
	    @Ignore
	    @Test
	    public void testFoo() throws Exception {  	
	    }
}  // end class BJM_4005B_TestCase
