package client_bjm;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Hashtable;
import java.util.Properties;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;

import testClient.TestInvocation;

public class NamedReplyJMSTestRunner extends BaseJMSTestRunner {
	
    private static String JNDI_PROPERTIES_FILE_NAME = "/jndi.properties";
    private static String JNDI_NAMING_PROVIDER_URL_PROPNAME = "java.naming.provider.url";
    private static String JNDI_NAMING_FACTORY_INITIAL_PROPNAME = "java.naming.factory.initial";
	
    /**
     * Invoke the test via a JMS message exchange.
     * @param input - input string
     * @return the output string from the JMS message exchange.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String invokeTest( String input ) throws Exception {

        String output = "No response";

        // Get JNDI properties and ensure they are set as required.
        Properties properties = new Properties();
        try {
            InputStream propertiesStream = this.getClass().getResourceAsStream(JNDI_PROPERTIES_FILE_NAME);
            properties.load(propertiesStream);
        } catch (IOException e) {	
            System.out.println("Unable to read JNDI properties file");
        } // end try


        // Get the name of the JMS Destination for this test case.
        String destinationName = ((NamedReplyJMSTestConfiguration)testConfiguration).getDestinationName();
        String calloutDestinationName = ((NamedReplyJMSTestConfiguration)testConfiguration).getCalloutDestinationName();
        String connectionFactoryName = ((NamedReplyJMSTestConfiguration)testConfiguration).getConnectionFactoryName();

        Hashtable env = new Hashtable();
        env.put(Context.INITIAL_CONTEXT_FACTORY, properties.getProperty(JNDI_NAMING_FACTORY_INITIAL_PROPNAME));
        env.put(Context.PROVIDER_URL, properties.getProperty(JNDI_NAMING_PROVIDER_URL_PROPNAME));
 
        ctx = new InitialContext(env);

        ConnectionFactory connFactory = (javax.jms.ConnectionFactory) ctx.lookup(connectionFactoryName);
        Destination dest = (javax.jms.Destination)ctx.lookup(destinationName);
        Destination cltdest = (javax.jms.Destination)ctx.lookup(calloutDestinationName);
        
        output = invokeTest(input,connFactory,dest,cltdest);
     
        return output;
    }
	
	/**
     * Invoke the test via a JMS message exchange.
     * @param input - input string
     * @param 
     * @return the output string from the JMS message exchange.
     * @throws Exception - if the JMS message exchange fails (e.g. the target service does not exist)
     */
    public String invokeTest( String input, ConnectionFactory connFactory, Destination dest, Destination cltdest ) throws Exception {
    	String output = "No response";

    	// Send message to the destination
        Connection conn = connFactory.createConnection();
        Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);

        Message request = createRequestMessage(input,sess);

        sendRequestMessage(sess,dest,request);
    	

        // Retrieve the reply message from the callout destibation
        if( cltdest != null ) {
            MessageConsumer msgConsumer = sess.createConsumer(cltdest);
            conn.start();
            Message response = msgConsumer.receive();

            output = checkReplyMessage(response);
        }

        sess.close();
        conn.close();

        return output;
    }

}
